// ***********************************************
// This example commands.js shows you how to
// create various custom commands and overwrite
// existing commands.
//
// For more comprehensive examples of custom
// commands please read more here:
// https://on.cypress.io/custom-commands
// ***********************************************
//
//
// -- This is a parent command --
// Cypress.Commands.add('login', (email, password) => { ... })
//
//
// -- This is a child command --
// Cypress.Commands.add('drag', { prevSubject: 'element'}, (subject, options) => { ... })
//
//
// -- This is a dual command --
// Cypress.Commands.add('dismiss', { prevSubject: 'optional'}, (subject, options) => { ... })
//
//
// -- This will overwrite an existing command --
// Cypress.Commands.overwrite('visit', (originalFn, url, options) => { ... })

import 'cypress-file-upload'
import '@testing-library/cypress/add-commands'
// import axe from 'axe-core'

// Cypress.Commands.add('injectAxe', () => {
//   cy.window({ log: false }).then((window) => {
//     window.axe = axe
//   })
// })

Cypress.Commands.add('g', (label, timeout = 8000) => {
  cy.get('[data-cy=' + label + ']:visible', { timeout: timeout })
})

Cypress.Commands.add('gi', (label) => {
  cy.get('[data-cy=' + label + ']')
})

Cypress.Commands.add('selectOption', ({ label, dataCy, value, index = 0 }) => {
  if(label) {
    cy.contains(label).eq(index).parent().children().eq(1).findByRole('button').click()
  } else {
    cy.get('[data-cy=' + dataCy + ']').eq(index).find("[data-cy=labeled-select]").parent().click()
  }
  cy.document().its('body').find('.v-menu__content').contains(value).click()
})

Cypress.Commands.add('selectVOption', (label, value) => {
  cy.get('[data-cy=' + label + ']').parent().click()
  cy.get(".v-menu__content").contains(value).click()
})

Cypress.Commands.add('selectDateOfBirth', (label, value1, value2, value3) => {
  cy.get('[data-cy=birth_month]').parent().click()
  cy.get(".v-menu__content").contains(value1).click()
  cy.get('[data-cy=birth_day]').parent().click()
  cy.get(".v-menu__content").contains(value2).click()
  cy.get('[data-cy=birth_year]').parent().click()
  cy.get(".v-menu__content").contains(value3).click()
})

Cypress.Commands.add('selectMonthDayYear', (label, value1, value2, value3) => {
  cy.get('[data-cy=month-select]').parent().click()
  cy.get(".v-menu__content").contains(value1).click()
  cy.get('[data-cy=day-select]').parent().click()
  cy.get(".v-menu__content").contains(value2).click()
  cy.get('[data-cy=year-select]').parent().click()
  cy.get(".v-menu__content").contains(value3).click()
})

Cypress.Commands.add('clickCheckbox', ({ dataCy, index }) => {
  cy.get('[data-cy=' + dataCy + ']').eq(index || 0).parent().click()
})

beforeEach(() => {
  cy.window().then((window) => {
    window.eval('console.clear()') // Clear the console between test runs
  })
})